@@ -2,9 +2,11 @@ name = "openapi_builder"
 path = name.lower().replace("-", "_").replace(" ", "_")
 # The version number should follow https://python.org/dev/peps/pep-0440 and
 # https://semver.org
-version = "0.1.1"
+version = "0.1.2"
 author = "Patrick Vogel"
 author_email = "patrickvogel@live.nl"
-description = ""
+description = (
+    "A Flask extension to automatically add OpenAPI documentation for your Flask app."
+)
 url = "https://github.com/FlyingBird95/openapi_builder"
 license = "MIT"
