@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 from openapi_builder.documentation import SwaggerDocumentation
@@ -5,7 +6,7 @@ from openapi_builder.specification import Parameter
 
 
 def add_documentation(
-    responses: Optional[Dict[Union[str, int], Any]] = None,
+    responses: Optional[Dict[Union[HTTPStatus, int], Any]] = None,
     input_schema: Optional[Any] = None,
     parameters: Optional[List[Parameter]] = None,
     summary: Optional[str] = None,
